@@ -468,7 +468,7 @@ def myaspp_encoder(in_channels, out_channels, stride):
 
 
 class ConvGRUCell(nn.Module):
-    def __init__(self, input_size, input_dim, hidden_dim, kernel_size, bias, dtype):
+    def __init__(self, input_size, input_dim, hidden_dim, kernel_size, bias = 0, dtype = float):
         """
         Initialize the ConvLSTM cell
         :param input_size: (int, int)
@@ -503,10 +503,8 @@ class ConvGRUCell(nn.Module):
                               padding=self.padding,
                               bias=self.bias)
 
-    def init_hidden(self, batch_size):
-        return (Variable(torch.zeros(batch_size, self.hidden_dim, self.height, self.width)).type(self.dtype))
 
-    def forward(self, input_tensor, h_cur = None):
+    def forward(self, input_tensor, h_cur):
         """
         :param self:
         :param input_tensor: (b, c, h, w)
@@ -516,9 +514,6 @@ class ConvGRUCell(nn.Module):
         :return: h_next,
             next hidden state
         """
-
-        if h_cur == None:
-            h_cur = init_hidden(input_tensor.size(0))
         combined = torch.cat([input_tensor, h_cur], dim=1)
         combined_conv = self.conv_gates(combined)
 
