@@ -155,7 +155,7 @@ class Dataset2D(Dataset):
         
 
 
-        if self.axis == None:
+        if self.oversampling == False:
             return x, y
         if self.oversampling:
             temp = np.random.uniform(0, 1)
@@ -211,7 +211,13 @@ class CustomDataset(Dataset):
         
 
         x = data['x']
-        y = data['y']
+        
+        try: 
+            y = data['y']
+        except KeyError:
+            print("y is missing")
+            y = None
+    
         if len(x.shape) == 3 and self.dim == '3d':
             #modality가 1개인 경우
             x = np.expand_dims(x, axis = 0)
