@@ -348,9 +348,10 @@ class UNet2d_Plus(nn.Module):
 
 
 class UNet2d_GRU(nn.Module):
-    def __init__(self, in_channels = 1, out_channels = 2, n_channels = 64, channel_bound = 1024, input_size = (48, 48)):
+    def __init__(self, in_channels = 1, out_channels = 2, n_channels = 64, channel_bound = 1024, input_size = (48, 48), device = 0):
         super().__init__()
         input_size = np.array(input_size)
+        self.device = device
         self.expand_channels = encoder_block_2d(in_channels, n_channels, stride = 1)
         self.conv_downsample1 = encoder_block_2d(n_channels, n_channels * 2)
         self.conv_downsample2 = encoder_block_2d(n_channels * 2, n_channels * 4)
@@ -376,16 +377,11 @@ class UNet2d_GRU(nn.Module):
         self.upsample3 = nn.Upsample(scale_factor=4)
         self.upsample2 = nn.Upsample(scale_factor=2)
 
-        self.gru1 = nn.Sequential(ConvGRUCell(input_size = input_size, input_dim = n_channels, hidden_dim = n_channels, kernel_size = 3),
-                                  ConvGRUCell(input_size = input_size, input_dim = n_channels, hidden_dim = n_channels, kernel_size = 3))
-        self.gru2 = nn.Sequential(ConvGRUCell(input_size = input_size //2, input_dim = n_channels*2, hidden_dim = n_channels*2, kernel_size = 3),
-                                  ConvGRUCell(input_size = input_size //2, input_dim = n_channels*2, hidden_dim = n_channels*2, kernel_size = 3))
-        self.gru3 = nn.Sequential(ConvGRUCell(input_size = input_size //4, input_dim = n_channels*4, hidden_dim = n_channels*4, kernel_size = 3),
-                                  ConvGRUCell(input_size = input_size //4, input_dim = n_channels*4, hidden_dim = n_channels*4, kernel_size = 3))
-        self.gru4 = nn.Sequential(ConvGRUCell(input_size = input_size //8, input_dim = n_channels*8, hidden_dim = n_channels*8, kernel_size = 3),
-                                  ConvGRUCell(input_size = input_size //8, input_dim = n_channels*8, hidden_dim = n_channels*8, kernel_size = 3))
-        self.gru5 = nn.Sequential(ConvGRUCell(input_size = input_size //16, input_dim = n_channels*16, hidden_dim = n_channels*16, kernel_size = 3),
-                                  ConvGRUCell(input_size = input_size //16, input_dim = n_channels*16, hidden_dim = n_channels*16, kernel_size = 3))
+        self.gru1 = ConvGRUCell(input_size = input_size, input_dim = n_channels, hidden_dim = n_channels, kernel_size = [3, 3])
+        self.gru2 = ConvGRUCell(input_size = input_size //2, input_dim = n_channels*2, hidden_dim = n_channels*2, kernel_size = [3, 3])
+        self.gru3 = ConvGRUCell(input_size = input_size //4, input_dim = n_channels*4, hidden_dim = n_channels*4, kernel_size = [3, 3])
+        self.gru4 = ConvGRUCell(input_size = input_size //8, input_dim = n_channels*8, hidden_dim = n_channels*8, kernel_size = [3, 3])
+        self.gru5 = ConvGRUCell(input_size = input_size //16, input_dim = n_channels*16, hidden_dim = n_channels*16, kernel_size = [3, 3])
 
     
     def forward(self, x, hidden_state = None):
@@ -402,11 +398,11 @@ class UNet2d_GRU(nn.Module):
             x_downsample3 = self.gru4(x_downsample3, hidden_state[3])
             x_downsample4 = self.gru5(x_downsample4, hidden_state[4])
         else:
-            x = self.gru1(x)
-            x_downsample1 = self.gru2(x_downsample1)
-            x_downsample2 = self.gru3(x_downsample2)
-            x_downsample3 = self.gru4(x_downsample3)
-            x_downsample4 = self.gru5(x_downsample4)
+            x = self.gru1(x, torch.zeros(x.shape).float().to(self.device))
+            x_downsample1 = self.gru2(x_downsample1, torch.zeros(x_downsample1.shape).float().to(self.device))
+            x_downsample2 = self.gru3(x_downsample2, torch.zeros(x_downsample2.shape).float().to(self.device))
+            x_downsample3 = self.gru4(x_downsample3, torch.zeros(x_downsample3.shape).float().to(self.device))
+            x_downsample4 = self.gru5(x_downsample4, torch.zeros(x_downsample4.shape).float().to(self.device))
 
         x_downsample4_up = self.conv_upsample1(x_downsample4)
         l4_output = self.decoder4(torch.cat((x_downsample4_up, x_downsample3), dim = 1))
@@ -423,6 +419,6 @@ class UNet2d_GRU(nn.Module):
         l4_output = self.upsample4(self.classifier4(l4_output))
 
         
-        return [l1_output, l2_output, l3_output, l4_output], [x, x_downsample1, x_downsample2, x_downsample3, x_downsample4]
+        return [l1_output, l2_output, l3_output, l4_output], [x.detach().clone(), x_downsample1.detach().clone(), x_downsample2.detach().clone(), x_downsample3.detach().clone(), x_downsample4.detach().clone()]
 
 
